CertifiedKey

Enum CertifiedKey 

#[non_exhaustive]
pub enum CertifiedKey { Ed25519(Ed25519Identity), RsaSha256Digest([u8; 32]), X509Sha256Digest([u8; 32]), Unrecognized(UnrecognizedKey), }
One of the data types that can be certified by an Ed25519Cert.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Ed25519(Ed25519Identity)

An Ed25519 public key, signed directly.



RsaSha256Digest([u8; 32])

The SHA256 digest of a DER-encoded RsaPublicKey



X509Sha256Digest([u8; 32])

The SHA256 digest of an X.509 certificate.



Unrecognized(UnrecognizedKey)

Some unrecognized key type.

Implementations

Source

impl CertifiedKey

pub fn key_type(&self) -> KeyType

Return the byte that identifies the type of this key.

pub fn as_bytes(&self) -> &[u8]

Return the bytes that are used for the body of this certified key or object.

pub fn as_ed25519(&self) -> Option<&Ed25519Identity>

If this is an Ed25519 public key, return Some(key). Otherwise, return None.