Ed25519Cert

Struct Ed25519Cert 

pub struct Ed25519Cert { /* private fields */ }
Structure for an Ed25519-signed certificate as described in Tor’s cert-spec.txt.

Implementations

Source

impl Ed25519Cert

pub fn builder() -> Ed25519CertBuilder

Return a new Ed25519CertBuilder to create and return a new signed Ed25519Cert.

Source

impl Ed25519Cert

pub fn decode(cert: &[u8]) -> BytesResult<KeyUnknownCert>

Try to decode a certificate from a byte slice.

This function returns an error if the byte slice is not completely exhausted.

Note that the resulting KeyUnknownCertificate is not checked for validity at all: you will need to provide it with an expected signing key, then check it for timeliness and well-signedness.

pub fn expiry(&self) -> SystemTime

Return the time at which this certificate becomes expired

pub fn is_expired_at(&self, when: SystemTime) -> bool

Return true iff this certificate will be expired at the time when.

This is inclusive, meaning that when == self.expiry() is still valid.

pub fn subject_key(&self) -> &CertifiedKey

Return the signed key or object that is authenticated by this certificate.

pub fn signing_key(&self) -> Option<&Ed25519Identity>

Return the ed25519 key that signed this certificate.

pub fn cert_type(&self) -> CertType

Return the type of this certificate.