pub struct Ed25519CertBuilder { /* private fields */ }Expand description
Builder for Ed25519Cert.
Implementations
Sourceimpl Ed25519CertBuilder
impl Ed25519CertBuilder
Sourcepub fn expiration(&mut self, expiration: SystemTime) -> &mut Self
pub fn expiration(&mut self, expiration: SystemTime) -> &mut Self
Set the approximate expiration time for this certificate.
(The time will be rounded forward to the nearest hour after the epoch.)
Sourcepub fn signing_key(&mut self, key: Ed25519Identity) -> &mut Self
pub fn signing_key(&mut self, key: Ed25519Identity) -> &mut Self
Set the signing key to be included with this certificate.
This is optional: you don’t need to include the signing key at all. If you do, it must match the key that you actually use to sign the certificate.
Sourcepub fn clear_signing_key(&mut self) -> &mut Self
pub fn clear_signing_key(&mut self) -> &mut Self
Remove any signing key previously set on this Ed25519CertBuilder.
Sourcepub fn encode_and_sign<S>(
&self,
skey: &S,
) -> Result<EncodedEd25519Cert, CertEncodeError>where
S: Ed25519PublicKey + Ed25519SigningKey,
pub fn encode_and_sign<S>(
&self,
skey: &S,
) -> Result<EncodedEd25519Cert, CertEncodeError>where
S: Ed25519PublicKey + Ed25519SigningKey,
Encode a certificate into a new vector, signing the result
with skey.
This function exists in lieu of a build() function, since we have a rule that
we don’t produce an Ed25519Cert except if the certificate is known to be
valid.