pub(crate) struct SignedWithEd25519Ext {
pub(crate) pk: Ed25519Identity,
}Expand description
Extension indicating that a key that signed a given certificate.
Fields
pk: Ed25519IdentityThe key that signed the certificate including this extension.