pub struct UncheckedCert { /* private fields */ }Expand description
A certificate that has been parsed, but whose signature and timeliness have not been checked.
Implementations
Sourceimpl UncheckedCert
impl UncheckedCert
Sourcepub fn dangerously_split(
self,
) -> Result<(SigCheckedCert, ValidatableEd25519Signature), CertError>
pub fn dangerously_split( self, ) -> Result<(SigCheckedCert, ValidatableEd25519Signature), CertError>
Split this unchecked cert into a component that assumes it has been checked, and a signature to validate.
Sourcepub fn peek_subject_key(&self) -> &CertifiedKey
pub fn peek_subject_key(&self) -> &CertifiedKey
Return subject key of the underlying cert.
Sourcepub fn peek_signing_key(&self) -> &Ed25519Identity
pub fn peek_signing_key(&self) -> &Ed25519Identity
Return signing key of the underlying cert.