pub struct Ed25519Cert {
pub(crate) exp_hours: ExpiryHours,
pub(crate) cert_type: CertType,
pub(crate) cert_key: CertifiedKey,
pub(crate) extensions: Vec<CertExt>,
pub(crate) signed_with: Option<Ed25519Identity>,
}Expand description
Structure for an Ed25519-signed certificate as described in Tor’s cert-spec.txt.
Fields
exp_hours: ExpiryHoursHow many hours after the epoch will this certificate expire?
cert_type: CertTypeType of the certificate; recognized values are in certtype::*
cert_key: CertifiedKeyThe key or object being certified.
extensions: Vec<CertExt>A list of extensions.
signed_with: Option<Ed25519Identity>The key that signed this cert.
Once the cert has been unwrapped from an KeyUnknownCert, this field will
be set. If there is a SignedWithEd25519 extension in
self.extensions, this will match it.
Implementations
Sourceimpl Ed25519Cert
impl Ed25519Cert
Sourcepub fn builder() -> Ed25519CertBuilder
pub fn builder() -> Ed25519CertBuilder
Return a new Ed25519CertBuilder to create and return a new signed
Ed25519Cert.
Sourceimpl Ed25519Cert
impl Ed25519Cert
Sourcepub fn decode(cert: &[u8]) -> BytesResult<KeyUnknownCert>
pub fn decode(cert: &[u8]) -> BytesResult<KeyUnknownCert>
Try to decode a certificate from a byte slice.
This function returns an error if the byte slice is not completely exhausted.
Note that the resulting KeyUnknownCertificate is not checked for validity at all: you will need to provide it with an expected signing key, then check it for timeliness and well-signedness.
Sourcepub fn expiry(&self) -> SystemTime
pub fn expiry(&self) -> SystemTime
Return the time at which this certificate becomes expired
Sourcepub fn is_expired_at(&self, when: SystemTime) -> bool
pub fn is_expired_at(&self, when: SystemTime) -> bool
Return true iff this certificate will be expired at the time when.
Sourcepub fn subject_key(&self) -> &CertifiedKey
pub fn subject_key(&self) -> &CertifiedKey
Return the signed key or object that is authenticated by this certificate.
Sourcepub fn signing_key(&self) -> Option<&Ed25519Identity>
pub fn signing_key(&self) -> Option<&Ed25519Identity>
Return the ed25519 key that signed this certificate.