Ed25519CertBuilder

Struct Ed25519CertBuilder 

pub struct Ed25519CertBuilder {
    pub(crate) exp_hours: Option<ExpiryHours>,
    pub(crate) cert_type: Option<CertType>,
    pub(crate) cert_key: Option<CertifiedKey>,
    pub(crate) extensions: Option<Vec<CertExt>>,
    pub(crate) signed_with: Option<Option<Ed25519Identity>>,
}
Builder for Ed25519Cert.

Fields

exp_hours: Option<ExpiryHours>

How many hours after the epoch will this certificate expire?

cert_type: Option<CertType>

Type of the certificate; recognized values are in certtype::*

cert_key: Option<CertifiedKey>

The key or object being certified.

extensions: Option<Vec<CertExt>>

A list of extensions.

signed_with: Option<Option<Ed25519Identity>>

The key that signed this cert.

Once the cert has been unwrapped from an KeyUnknownCert, this field will be set. If there is a SignedWithEd25519 extension in self.extensions, this will match it.

Implementations

Source

impl Ed25519CertBuilder

pub fn expiration(&mut self, expiration: SystemTime) -> &mut Self

Set the approximate expiration time for this certificate.

(The time will be rounded forward to the nearest hour after the epoch.)

pub fn signing_key(&mut self, key: Ed25519Identity) -> &mut Self

Set the signing key to be included with this certificate.

This is optional: you don’t need to include the signing key at all. If you do, it must match the key that you actually use to sign the certificate.

pub fn clear_signing_key(&mut self) -> &mut Self

Remove any signing key previously set on this Ed25519CertBuilder.

pub fn encode_and_sign<S>( &self, skey: &S, ) -> Result<EncodedEd25519Cert, CertEncodeError>

Encode a certificate into a new vector, signing the result with skey.

This function exists in lieu of a build() function, since we have a rule that we don’t produce an Ed25519Cert except if the certificate is known to be valid.

Source

impl Ed25519CertBuilder

pub fn cert_type(&mut self, value: CertType) -> &mut Self

Type of the certificate; recognized values are in certtype::*

pub fn cert_key(&mut self, value: CertifiedKey) -> &mut Self

The key or object being certified.

pub(crate) fn create_empty() -> Self

Create an empty builder, with all fields set to None or PhantomData.